@@ -9,6 +9,6 @@ START_HEALTH = 5000
 
 class HealthRoom(BaseRoom, ABC):
     start_health = START_HEALTH
-    phase_count: int = 5
+    guess_duration: float = 15  # Time between first guess to phase ending
     phases: list[HealthPhase] = []
-    guesses: list[dict[str, Guess]] = []  # user ID to guess
+    guesses: list[dict[str, Guess]] = []  # User ID to guess
