@@ -1,9 +1,8 @@
 import uuid
-from abc import ABC, abstractmethod
 from datetime import datetime
 from enum import StrEnum
 
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, Field, validator
 
 
 class RoomMode(StrEnum):
@@ -16,22 +15,22 @@ class RoomStatus(StrEnum):
     waiting = 'waiting'
     waiting_to_start = 'waitingToStart'
     running = 'running'
+    closed = 'closed'
 
 
-class BaseRoom(BaseModel, ABC):
+class BaseRoom(BaseModel):
     id: str = Field(alias='id_', default_factory=lambda: str(uuid.uuid4()))
     map: str = 'world'
     status: RoomStatus = RoomStatus.waiting
     create_time: datetime = Field(default_factory=datetime.now)
     start_time: datetime | None = None
+    mode: str = None
 
-    def __init__(self, **data):
-        if 'mode' not in data:
-            data['mode'] = self.get_mode()
-        super().__init__(**data)
+    @validator("mode", always=True)
+    def compute_mode(cls, value):
+        return cls.get_mode()
 
     @staticmethod
-    @abstractmethod
     def get_mode() -> RoomMode:
         pass
 
